<?php

define('SYSPATH', '');

require_once 'test/fixtures/authenticated.php';
require_once 'sysnagios/models/sysnagios.php';
require_once 'sysnagios/controllers/sysnagios.php';

class SysNagios_Test extends PHPUnit_Framework_TestCase
{

	/**
	 * Tests input values
	 * May be of types: IP/FQDN/hostname
	 *
	 * @return void
	 **/
	function test_address_resolution()
	{
		$tests = array(
			'ip' => '172.27.86.141',
			'fqdn' => 'merlin-master1.dev.op5.com',
			'hostname' => 'merlin-master1'
		);
		foreach ($tests as $type => $test) {
			$return = SysNagios_Model::parse_host_address($test);
			$this->assertTrue(is_array($return), "Expected a returned array, got " . gettype($return));
			$this->assertTrue(isset($return['ip']), 'No ip was returned');
			$this->assertTrue(isset($return['hostname']), 'No hostname was returned');
		}
	}

	/**
	 * Test parsing of mon node show
	 * Should return an array of nodes with an array of hostgroups
	 *
	 * @return void
	 **/
	function test_mon_node_show_parse()
	{
		// PHP, why u so silly
		$mon_node_show = file(__DIR__."/fixtures/mon_node_show", FILE_IGNORE_NEW_LINES);
		$node_list = SysNagios_Model::parse_mon_node_show($mon_node_show);
		$this->assertTrue(is_array($node_list), "Expected a returned array, got " . gettype($node_list));
		foreach ($node_list as $node) {
			$this->assertTrue(isset($node['address']), "No address is set on node");
			$this->assertTrue(isset($node['type']), "No type is set on node");
			$this->assertTrue(isset($node['name']), "No name is set on node");
			$this->assertTrue(isset($node['port']), "No port is set on node");
			if ($node['type'] === 'poller') {
				$this->assertTrue(isset($node['hostgroup']), "Pollers should have hostgroups assigned");
			}
		}
	}

	/**
	 * Test that hostgroup membership function works
	 *
	 * @return void
	 **/
	function disabled_test_host_hg_membership()
	{
		$hostgroups =  SysNagios_Model::get_hostgroup_from_member("monitor");
		$this->assertTrue(is_array($hostgroups), "Expected a returned array, got " . gettype($hostgroups));
	}

	/**
	 * Create a lock file, check that it is present, delete the lock-file
	 *
	 * @return void
	 **/
	function test_lock_file()
	{
		// Test self and remote node
		$nodes = array("--self");
		foreach ($nodes as $node) {
			$lock_created = SysNagios_Model::create_lock_file($node);
			$this->assertTrue($lock_created, "Lock-file creation failed: " . var_export($lock_created, true));
			$lock_exists = SysNagios_Model::lock_file_exists($node);
			$this->assertTrue($lock_exists, "Should have reporteda lock file was present");
			$lock_removed = SysNagios_Model::remove_lock_file($node);
			$this->assertTrue($lock_removed, "Lock-file deletion failed: " . var_export($lock_removed, true));
		}
	}

	/**
	 * Test for script existance
	 *
	 * @return void
	 **/
	function test_script_exists()
	{
		$nodes = array("--self");
		$path = "/usr/local/sysnagios_server/getconfigs.sh";
		foreach ($nodes as $node) {
			$script_exists = SysNagios_Model::getconfigs_exist($path, $node);
			$this->assertFalse($script_exists, "Expected script file to not exist but it apparently does");
		}
	}

	/**
	 * Test host-node matching
	 *
	 * @return void
	 **/
	function test_node_matching()
	{
		$mon_node_show = file(__DIR__."/fixtures/mon_node_show", FILE_IGNORE_NEW_LINES);
		$nodes = SysNagios_Model::parse_mon_node_show($mon_node_show);
		// Test that a node is matched
		$host = "monitor";
		$hostgroups = array('unix-servers', 'monitoring');
		$node = SysNagios_Model::match_node($host, $hostgroups, $nodes);
		$this->assertSame($node, "merlin-poller4", "Expected returned node to be 'merlin-poller4' got: " . $node);
		// Test where no node has a hostgroup that matches given hostgroup, return --self
		$host = "foo";
		$hostgroups = array('foogroup');
		$node = SysNagios_Model::match_node($host, $hostgroups, $nodes);
		$this->assertSame($node, "--self", "Expected returned node to be '--self' got: " . $node);
	}

} // END CLASS
